.. _contents:

#################################
 Camelot Documentation contents
#################################

.. toctree::

   tutorial/index.rst
   doc/index.rst
   advanced/index.rst

   license.rst
   copyright.rst
